@@ -1,13 +1,13 @@
 # SPDX-License-Identifier: Apache-2.0
 import hashlib
-from typing import Any, IO, List, MutableSequence, Optional, Tuple, Union, cast
+from typing import IO, Any, List, MutableSequence, Optional, Tuple, Union, cast
 
 from ruamel import yaml
 from schema_salad.exceptions import ValidationException
 from schema_salad.utils import json_dumps
 
 import cwl_utils.parser
-import cwl_utils.parser.cwl_v1_0 as cwl
+import cwl_utils.parser.cwl_v1_2 as cwl
 import cwl_utils.parser.utils
 from cwl_utils.errors import WorkflowException
 
@@ -42,22 +42,27 @@ def content_limit_respected_read_bytes(f: IO[bytes]) -> bytes:
     """
     Read file content up to 64 kB as a byte array.
 
-    Truncate content for larger files.
+    Throw exception for larger files (see https://www.commonwl.org/v1.2/Workflow.html#Changelog).
     """
-    return f.read(CONTENT_LIMIT)
+    contents = f.read(CONTENT_LIMIT + 1)
+    if len(contents) > CONTENT_LIMIT:
+        raise WorkflowException(
+            "file is too large, loadContents limited to %d bytes" % CONTENT_LIMIT
+        )
+    return contents
 
 
 def content_limit_respected_read(f: IO[bytes]) -> str:
     """
     Read file content up to 64 kB as an utf-8 encoded string.
 
-    Truncate content for larger files.
+    Throw exception for larger files (see https://www.commonwl.org/v1.2/Workflow.html#Changelog).
     """
     return content_limit_respected_read_bytes(f).decode("utf-8")
 
 
 def convert_stdstreams_to_files(clt: cwl.CommandLineTool) -> None:
-    """Convert stdout and stderr type shortcuts to files."""
+    """Convert stdin, stdout and stderr type shortcuts to files."""
     for out in clt.outputs:
         if out.type == "stdout":
             if out.outputBinding is not None:
@@ -85,6 +90,22 @@ def convert_stdstreams_to_files(clt: cwl.CommandLineTool) -> None:
                 )
             out.type = "File"
             out.outputBinding = cwl.CommandOutputBinding(glob=clt.stderr)
+    for inp in clt.inputs:
+        if inp.type == "stdin":
+            if inp.inputBinding is not None:
+                raise ValidationException(
+                    "Not allowed to specify unputBinding when using stdin shortcut."
+                )
+            if clt.stdin is not None:
+                raise ValidationException(
+                    "Not allowed to specify stdin path when using stdin type shortcut."
+                )
+            else:
+                clt.stdin = (
+                    "$(inputs.%s.path)"
+                    % cast(str, inp.id).rpartition("#")[2].split("/")[-1]
+                )
+                inp.type = "File"
 
 
 def merge_flatten_type(src: Any) -> Any:
@@ -101,6 +122,7 @@ def type_for_source(
     sourcenames: Union[str, List[str]],
     parent: Optional[cwl.Workflow] = None,
     linkMerge: Optional[str] = None,
+    pickValue: Optional[str] = None,
 ) -> Any:
     """Determine the type for the given sourcenames."""
     scatter_context: List[Optional[Tuple[int, str]]] = []
@@ -117,6 +139,10 @@ def type_for_source(
             new_type = cwl.ArraySchema(items=new_type, type="array")
         elif linkMerge == "merge_flattened":
             new_type = merge_flatten_type(new_type)
+        if pickValue is not None:
+            if isinstance(new_type, cwl.ArraySchema):
+                if pickValue in ["first_non_null", "the_only_non_null"]:
+                    new_type = new_type.items
         return new_type
     new_type = []
     for p, sc in zip(params, scatter_context):
@@ -139,13 +165,16 @@ def type_for_source(
     if len(new_type) == 1:
         new_type = new_type[0]
     if linkMerge == "merge_nested":
-        return cwl.ArraySchema(items=new_type, type="array")
+        new_type = cwl.ArraySchema(items=new_type, type="array")
     elif linkMerge == "merge_flattened":
-        return merge_flatten_type(new_type)
+        new_type = merge_flatten_type(new_type)
     elif isinstance(sourcenames, List):
-        return cwl.ArraySchema(items=new_type, type="array")
-    else:
-        return new_type
+        new_type = cwl.ArraySchema(items=new_type, type="array")
+    if pickValue is not None:
+        if isinstance(new_type, cwl.ArraySchema):
+            if pickValue in ["first_non_null", "the_only_non_null"]:
+                new_type = new_type.items
+    return new_type
 
 
 def param_for_source_id(
@@ -153,11 +182,11 @@ def param_for_source_id(
     sourcenames: Union[str, List[str]],
     parent: Optional[cwl.Workflow] = None,
     scatter_context: Optional[List[Optional[Tuple[int, str]]]] = None,
-) -> Union[List[cwl.InputParameter], cwl.InputParameter]:
+) -> Union[List[cwl.WorkflowInputParameter], cwl.WorkflowInputParameter]:
     """Find the process input parameter that matches one of the given sourcenames."""
     if isinstance(sourcenames, str):
         sourcenames = [sourcenames]
-    params: List[cwl.InputParameter] = []
+    params: List[cwl.WorkflowInputParameter] = []
     for sourcename in sourcenames:
         if not isinstance(process, cwl.Workflow):
             for param in process.inputs:
@@ -209,26 +238,27 @@ def param_for_source_id(
                                         ):
                                             params.append(output)
                                             if scatter_context is not None:
-                                                if isinstance(step.scatter, str):
-                                                    scatter_context.append(
-                                                        (
-                                                            1,
-                                                            step.scatterMethod
-                                                            or "dotproduct",
+                                                if scatter_context is not None:
+                                                    if isinstance(step.scatter, str):
+                                                        scatter_context.append(
+                                                            (
+                                                                1,
+                                                                step.scatterMethod
+                                                                or "dotproduct",
+                                                            )
                                                         )
-                                                    )
-                                                elif isinstance(
-                                                    step.scatter, MutableSequence
-                                                ):
-                                                    scatter_context.append(
-                                                        (
-                                                            len(step.scatter),
-                                                            step.scatterMethod
-                                                            or "dotproduct",
+                                                    elif isinstance(
+                                                        step.scatter, MutableSequence
+                                                    ):
+                                                        scatter_context.append(
+                                                            (
+                                                                len(step.scatter),
+                                                                step.scatterMethod
+                                                                or "dotproduct",
+                                                            )
                                                         )
-                                                    )
-                                                else:
-                                                    scatter_context.append(None)
+                                                    else:
+                                                        scatter_context.append(None)
     if len(params) == 1:
         return params[0]
     elif len(params) > 1:
