@@ -151,7 +151,7 @@ def test_v1_2_workflow_top_level_sf_expr_array() -> None:
 def test_v1_0_step_valuefrom_expr_multisource() -> None:
     """Convert a valueFrom expression that has multiple sources."""
     result, modified = traverse0(
-        parser.load_document(str(HERE / "../testdata/step-valuefrom2-wf_v10.cwl")),
+        parser.load_document(str(HERE / "../testdata/step-valuefrom2-wf_v1_0.cwl")),
         False,
         False,
         False,
@@ -162,7 +162,7 @@ def test_v1_0_step_valuefrom_expr_multisource() -> None:
 def test_v1_1_step_valuefrom_expr_multisource() -> None:
     """Convert a valueFrom expression that has multiple sources."""
     result, modified = traverse1(
-        parser1.load_document(str(HERE / "../testdata/step-valuefrom2-wf_v11.cwl")),
+        parser1.load_document(str(HERE / "../testdata/step-valuefrom2-wf_v1_1.cwl")),
         False,
         False,
         False,
@@ -173,7 +173,7 @@ def test_v1_1_step_valuefrom_expr_multisource() -> None:
 def test_v1_2_step_valuefrom_expr_multisource() -> None:
     """Convert a valueFrom expression that has multiple sources."""
     result, modified = traverse2(
-        parser2.load_document(str(HERE / "../testdata/step-valuefrom2-wf_v12.cwl")),
+        parser2.load_document(str(HERE / "../testdata/step-valuefrom2-wf_v1_2.cwl")),
         False,
         False,
         False,
@@ -184,7 +184,7 @@ def test_v1_2_step_valuefrom_expr_multisource() -> None:
 def test_v1_0_step_valuefrom_expr_sibling_inputs() -> None:
     """Convert a valueFrom expression from a step input that has uninvolved sibling inputs."""
     result, modified = traverse0(
-        parser.load_document(str(HERE / "../testdata/step-valuefrom3-wf_v10.cwl")),
+        parser.load_document(str(HERE / "../testdata/step-valuefrom3-wf_v1_0.cwl")),
         False,
         False,
         False,
@@ -195,7 +195,7 @@ def test_v1_0_step_valuefrom_expr_sibling_inputs() -> None:
 def test_v1_1_step_valuefrom_expr_sibling_inputs() -> None:
     """Convert a valueFrom expression from a step input that has uninvolved sibling inputs."""
     result, modified = traverse1(
-        parser1.load_document(str(HERE / "../testdata/step-valuefrom3-wf_v11.cwl")),
+        parser1.load_document(str(HERE / "../testdata/step-valuefrom3-wf_v1_1.cwl")),
         False,
         False,
         False,
@@ -206,7 +206,7 @@ def test_v1_1_step_valuefrom_expr_sibling_inputs() -> None:
 def test_v1_2_step_valuefrom_expr_sibling_inputs() -> None:
     """Convert a valueFrom expression from a step input that has uninvolved sibling inputs."""
     result, modified = traverse2(
-        parser2.load_document(str(HERE / "../testdata/step-valuefrom3-wf_v12.cwl")),
+        parser2.load_document(str(HERE / "../testdata/step-valuefrom3-wf_v1_2.cwl")),
         False,
         False,
         False,
